#!/bin/bash

ds=$(date +%Y%m%d%H%M%S)
cp -pa /etc/httpd/conf/httpd.conf /etc/httpd/conf/httpd.conf.$ds
cp -pa /etc/httpd/conf.d/userdir.conf /etc/httpd/conf.d/userdir.conf.$ds
cp -pa /etc/httpd/conf.d/autoindex.conf /etc/httpd/conf.d/autoindex.conf.$ds

TIMESTAMP=`date`
STAMP="On $TIMESTAMP %{name}"

#
# To understand what the lines below are doing you will need to review the
# augeas documentation.
# The short version is:
#
#   *[arg = 'x']  will match an item that has a sub item named 'arg' with a
#                 value of x.  It will match as many as there are.
#
#   arg[. = 'Indexes']  will match the element of an array whose value is
#                       Indexes
#

#
# the trick with the comments is far more complex
#
#  Insert the comment before the node that begins the line
#  Find the comment block before the node
#  Find the end element
#  Then set it
#

# we do the comments in their own block as they might fail
# if they fail anything else run during that block also fails
# as it only saves when asked.  This isn't a database it is
# file manipulation.  Transactions are not atomic
#

########################################################################

TMPFILE=`mktemp`
# expect the quotation marks to be either missing or "
cat > $TMPFILE <<CHANGEWEBROOTCOMMENT
ins #comment before /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/html["]*')]/*[arg = 'Indexes']
set /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/html["]*')]/#comment[following-sibling::*[1][arg = 'Indexes']] "$STAMP removed Indexes from Options"

ins #comment before /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/html["]*')]/*[. = 'AllowOverride']
set /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/html["]*')]/#comment[following-sibling::*[1][arg = 'None']] "$STAMP added Indexes to AllowOverride"

save

CHANGEWEBROOTCOMMENT

# add comments about:
# removing the 'Indexes' option from /var/www/html Options list
# Allowing .htaccess to set 'Indexes'
augtool < $TMPFILE >/dev/null 2>&1
rm -f $TMPFILE

########################################################################

TMPFILE=`mktemp`
# expect the quotation marks to be either missing or "
cat > $TMPFILE <<CHANGEWEBROOT
rm /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/html["]*')]/*[arg = 'Indexes']/arg[. = 'Indexes']

set /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/html["]*')]/*[. = 'AllowOverride']/*[. = 'None'] Indexes

save

CHANGEWEBROOT

# actually do the work:
# remove the 'Indexes' option from /var/www/html Options list
# Allow .htaccess to set 'Indexes'
augtool < $TMPFILE >/dev/null 2>&1
rm -f $TMPFILE

########################################################################
########################################################################

TMPFILE=`mktemp`
# expect the quotation marks to be either missing or "
 cat > $TMPFILE <<CHANGEICONSCOMMENT
ins #comment before /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/icons["]*')]/*[arg = 'Indexes']
set /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/icons["]*')]/#comment[following-sibling::*[1][arg = 'Indexes']] "$STAMP removed Indexes from Options"

ins #comment before /files/etc/httpd/conf.d/autoindex.conf/Directory[arg = '"/usr/share/httpd/icons"']/directive[. = "Options" and arg = "Indexes"]
set /files/etc/httpd/conf.d/autoindex.conf/Directory[arg = '"/usr/share/httpd/icons"']/#comment[following-sibling::directive[. = "Options" and arg = "Indexes"]] "$STAMP removed Indexes from Options"
save

CHANGEICONSCOMMENT

# add comment about:
# removing the 'Indexes' option from /var/www/icons Options list
augtool < $TMPFILE >/dev/null 2>&1
rm -f $TMPFILE

########################################################################

TMPFILE=`mktemp`
# expect the quotation marks to be either missing or "
 cat > $TMPFILE <<CHANGEICONS

rm /files/etc/httpd/conf/httpd.conf/*[arg =~ regexp('["]*/var/www/icons["]*')]/*[arg = 'Indexes']/arg[. = 'Indexes']
rm /files/etc/httpd/conf.d/autoindex.conf/Directory[arg = '"/usr/share/httpd/icons"']/directive[. = "Options"]/arg[. = "Indexes"]
save

CHANGEICONS

# actually do the work:
# remove the 'Indexes' option from /var/www/icons Options list
augtool < $TMPFILE >/dev/null 2>&1
rm -f $TMPFILE

########################################################################
########################################################################

TMPFILE=`mktemp`
# If we happen to find the default options for mod_userdir
# remove Indexes from the list, but add it to AllowOverride
# We're checking for both the SL6 and SL7 default.
 cat > $TMPFILE <<CHANGEUSERDIR
set /files/etc/httpd/conf/httpd.conf/*[ . = 'AllowOverride FileInfo AuthConfig Limit' ] 'AllowOverride FileInfo AuthConfig Limit Indexes'
set /files/etc/httpd/conf/httpd.conf/*[ . = 'Options MultiViews Indexes SymLinksIfOwnerMatch IncludesNoExec' ] 'Options MultiViews SymLinksIfOwnerMatch IncludesNoExec'

ins #comment before /files/etc/httpd/conf.d/userdir.conf/Directory[arg = '"/home/*/public_html"']/directive[. = "Options" and arg = "Indexes"]
set /files/etc/httpd/conf.d/userdir.conf/Directory[arg = '"/home/*/public_html"']/#comment[following-sibling::directive[. = "Options" and arg = "Indexes"]] "$STAMP removed Indexes from Options"
rm /files/etc/httpd/conf.d/userdir.conf/Directory[arg = '"/home/*/public_html"']/directive[. = 'Options']/arg[. = 'Indexes']
save

CHANGEUSERDIR

# remove the 'Indexes' option from mod_userdir sample Options list
augtool < $TMPFILE >/dev/null 2>&1
rm -f $TMPFILE

