Name: fermilab-conf_apache-no-browsable-directory
Summary: Change the default httpd.conf to disable autoindex
Version: 1.2
Release: 2
License: GPL
Group: Fermilab
BuildArch: noarch
BuildRequires: bash coreutils
Source0: %{name}.sh
Requires: httpd
Requires(post): coreutils augeas >= 0.9.0-5 policycoreutils systemd
Obsoletes: zz_apache_no_browsable_directory

%description
This modifies the /etc/httpd/conf/httpd.conf and /etc/httpd/conf.d/userdir.conf
files using augeas so that mod_autoindex does not list your directories out by
default.

This will remove 'Indexes' from your 'Options' list for '/var/www/html'
and '/var/www/icons'.  It will also remove 'Indexes' from the sample
options list for mod_userdir (~username directories).

For this change to take effect you must restart httpd.

You can still enable this option with a .htaccess file or by editing the config
file yourself.

To return indexes to working state you will need to add:

 Options +Indexes

to either your apache config or your .htaccess file

See: http://httpd.apache.org/docs/2.4/mod/mod_autoindex.html

Requirement from: CS-doc-4807

%prep

%build

%install
rm -rf $RPM_BUILD_ROOT
%{__install} -D %{SOURCE0} %{buildroot}/%{_libexecdir}/%{name}/%{name}.sh

%clean
rm -rf $RPM_BUILD_ROOT

%check
bash -n %{buildroot}/%{_libexecdir}/%{name}/%{name}.sh

%files
%defattr(0644,root,root,0755)
%doc
%attr(0750,root,root) %{_libexecdir}/%{name}/%{name}.sh

%triggerin -p /bin/bash -- httpd
##################### BEGIN Snippet #################################
set -u
TRIGGER_ON_PACKAGE_NAME='httpd'
# The following script snippet attempts to classify why we were called:
#  - on first install of either package, RUN_TRIGGER == "Initial"
#  - on upgrade of _THIS_ package, RUN_TRIGGER == "UpgradeSELF"
#  - on upgrade of the TRIGGERON package, RUN_TRIGGER == "UpgradeTRIGGERON"
#  - on upgrade of the TRIGGERON package but initial install of _THIS_ package, RUN_TRIGGER == "InitialSELFUpgradeTRIGGERON"
#  - on upgrade of the BOTH packages, RUN_TRIGGER == "UPGRADEALL"

CURRENT_INSTALLS_OF_THIS_PACKAGE=${1}
TRIGGER_ON_PACKAGE=${2}

RUN_TRIGGER="NO"
if [[ ${TRIGGER_ON_PACKAGE} -eq 1 ]]; then
    # We only get here if we are NOT doing an upgrade of the trigger package
    if [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -eq 0 ]]; then
        # We only get here if we are removing _THIS_ package
        RUN_TRIGGER="UninstallSELF"
    elif [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -eq 1 ]]; then
        # We only get here if we are NOT doing an upgrade of the trigger package
        #                and we are installing _THIS_ package for the first time
        RUN_TRIGGER="Initial"
    elif [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -gt 1 ]]; then
        # We only get here if we are NOT doing an upgrade of the trigger package
        #                and we are upgrading _THIS_ package
        RUN_TRIGGER="UpgradeSELF"
    fi
elif [[ ${TRIGGER_ON_PACKAGE} -gt 1 ]]; then
    # We only get here if we are doing an upgrade of the trigger package
    if [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -eq 1 ]]; then
        # We get here if we are doing an upgrade of the trigger package
        #                     and we are NOT upgrading _THIS_ package
        RUN_TRIGGER="UpgradeTRIGGERON"

        #  But, are we installing _THIS_ package as a part of a dependency
        #       resolution chain?
        _THIS_TID=$(rpm -q --qf "%{INSTALLTID}\n" %{NAME})
        # Find the last installed (ie the current) TRIGGER_ON_PACKAGE_NAME's transaction
        TID=$(rpm -q --qf "%{INSTALLTID}\n" ${TRIGGER_ON_PACKAGE_NAME} --last |grep -v ${TRIGGER_ON_PACKAGE_NAME} | head -1)
        if [[ "${_THIS_TID}" == "${TID}" ]]; then
            # if the transaction ID of _THIS_ package is identical to the
            #  transaction ID of an installed TRIGGER_ON_PACKAGE_NAME
            # then, we must be upgrading the trigger package and
            # installing _THIS_ package
            RUN_TRIGGER="InitialSELFUpgradeTRIGGERON"
        fi
    elif [[ ${CURRENT_INSTALLS_OF_THIS_PACKAGE} -gt 1 ]]; then
        # We only get here if we are doing an upgrade of the trigger package
        #                     and we are upgrading _THIS_ package
        RUN_TRIGGER="UpgradeALL"
    fi
elif [[ ${TRIGGER_ON_PACKAGE} -eq 0 ]]; then
    # We only get here if we are removing the trigger package
    RUN_TRIGGER="UninstallTRIGGERON"
fi

if [[ "${RUN_TRIGGER}" == "NO" ]]; then
    # If we got here if:
    #  some kind of edge case appeared......
    echo "##################################" >&2
    echo "%{NAME}: Not sure what this means"  >&2
    echo "CURRENT_INSTALLS_OF_THIS_PACKAGE = ${CURRENT_INSTALLS_OF_THIS_PACKAGE}"  >&2
    echo "TRIGGER_ON_PACKAGE (${TRIGGER_ON_PACKAGE_NAME}) = ${TRIGGER_ON_PACKAGE}" >&2
    echo "##################################" >&2
    exit 1
fi

##################### End of Snippet #################################

if [[ "${RUN_TRIGGER}" == "UpgradeTRIGGERON" ]]; then
    # If we got here if:
    #  a) we are upgrading the trigger package, but not _THIS_ package
    #       so we've already run this once and will not run it again.

    # If the user changed the config themselves, we shouldn't undo their work
    #  if we decide we need to, we can always alter the behavior in the next
    #  version of this package.
    exit 0
fi

# # #
# This way external scripts/config tools can call these changes if they want
%{_libexecdir}/%{name}/%{name}.sh

systemctl condrestart httpd.service

##########################################################################
%changelog
* Tue Nov 10 2015 Kevin M. Hill <kevinh@fnal.gov> 1.2-2
- Switch to systemctl condrestart from is-running, restart

* Tue Nov 10 2015 Kevin M. Hill <kevinh@fnal.gov> 1.2-1
- Move action to a script, update trigger code.

* Wed Aug 26 2015 Kevin M. Hill <kevinh@fnal.gov> 1.1-1
- Add support for SL7 conf.d/userdir.conf file.

* Thu Jan 17 2013 Pat Riehecky <riehecky@fnal.gov> 1.0-4
- Comment addition is now in its own block so that failure
   to leave a comment doesn't prevent the config changes
   from happening.

* Tue Dec 4 2012 Pat Riehecky <riehecky@fnal.gov> 1.0-3
- Sets up mod_userdir with no indexes too
- Now leaves a comment behind saying what it did
- Now archives httpd.conf before making the edits

* Fri Nov 30 2012 Pat Riehecky <riehecky@fnal.gov> 1.0-2
- Improved internal documentation

* Wed Nov 28 2012 Pat Riehecky <riehecky@fnal.gov> 1.0-1
- Trigger is now far more selective about when it runs

* Tue Nov 27 2012 Pat Riehecky <riehecky@fnal.gov> 1.0-0
- Initial build at the request of computing security
